==> haskell-strict-list-0.1.5-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 strict-list
version:              0.1.5
visibility:           public
id:                   strict-list-0.1.5-67ITEIqZYz2CLR8Crji3HX
key:                  strict-list-0.1.5-67ITEIqZYz2CLR8Crji3HX
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

abi:                  c63b5ebb41e27f9104c74e66e3212039
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-8.10.4/site-local/strict-list-0.1.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/strict-list-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/strict-list-0.1.5
hs-libraries:         HSstrict-list-0.1.5-67ITEIqZYz2CLR8Crji3HX
depends:
    base-4.14.1.0 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    semigroupoids-5.3.5-I2gNxmHDk9w9wpXtVDf1vz

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-list-0.1.5-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 strict-list
version:              0.1.5
visibility:           public
id:                   strict-list-0.1.5-LZaSUpwmYm58j9dL2vRE7I
key:                  strict-list-0.1.5-LZaSUpwmYm58j9dL2vRE7I
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

abi:                  16d7e52558a3848e6e8d9eecf9761658
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-8.10.4/site-local/strict-list-0.1.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/strict-list-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/strict-list-0.1.5
hs-libraries:         HSstrict-list-0.1.5-LZaSUpwmYm58j9dL2vRE7I
depends:
    base-4.14.1.0 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    semigroupoids-5.3.5-CawDYuniB5DJS3Hmwpr0pb

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
